==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecHttpRouteMatchPathArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteMatchPathArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property exact The exact path to match on.
 * @property regex The regex used to match the path.
 */
public data class GatewayRouteSpecHttpRouteMatchPathArgs(
    public val exact: Output<String>? = null,
    public val regex: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteMatchPathArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteMatchPathArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteMatchPathArgs.builder()
            .exact(exact?.applyValue({ args0 -> args0 }))
            .regex(regex?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GatewayRouteSpecHttpRouteMatchPathArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecHttpRouteMatchPathArgsBuilder internal constructor() {
    private var exact: Output<String>? = null

    private var regex: Output<String>? = null

    /**
     * @param value The exact path to match on.
     */
    @JvmName("tmewvbxpgvgbqkxo")
    public suspend fun exact(`value`: Output<String>) {
        this.exact = value
    }

    /**
     * @param value The regex used to match the path.
     */
    @JvmName("ebynquvvdorujhnd")
    public suspend fun regex(`value`: Output<String>) {
        this.regex = value
    }

    /**
     * @param value The exact path to match on.
     */
    @JvmName("nkbrukaqvbboawjc")
    public suspend fun exact(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exact = mapped
    }

    /**
     * @param value The regex used to match the path.
     */
    @JvmName("dkeeeupbrtduobcj")
    public suspend fun regex(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.regex = mapped
    }

    internal fun build(): GatewayRouteSpecHttpRouteMatchPathArgs =
        GatewayRouteSpecHttpRouteMatchPathArgs(
            exact = exact,
            regex = regex,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecHttpRouteMatchPathArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteMatchPathArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property exact The exact path to match on.
 * @property regex The regex used to match the path.
 */
public data class GatewayRouteSpecHttpRouteMatchPathArgs(
    public val exact: Output<String>? = null,
    public val regex: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteMatchPathArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteMatchPathArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteMatchPathArgs.builder()
            .exact(exact?.applyValue({ args0 -> args0 }))
            .regex(regex?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GatewayRouteSpecHttpRouteMatchPathArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecHttpRouteMatchPathArgsBuilder internal constructor() {
    private var exact: Output<String>? = null

    private var regex: Output<String>? = null

    /**
     * @param value The exact path to match on.
     */
    @JvmName("ggbytwofubiwvfvm")
    public suspend fun exact(`value`: Output<String>) {
        this.exact = value
    }

    /**
     * @param value The regex used to match the path.
     */
    @JvmName("hswpqravopkvnfyi")
    public suspend fun regex(`value`: Output<String>) {
        this.regex = value
    }

    /**
     * @param value The exact path to match on.
     */
    @JvmName("mqysfkrhisuktbeu")
    public suspend fun exact(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exact = mapped
    }

    /**
     * @param value The regex used to match the path.
     */
    @JvmName("haktuoxuctyahvkm")
    public suspend fun regex(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.regex = mapped
    }

    internal fun build(): GatewayRouteSpecHttpRouteMatchPathArgs =
        GatewayRouteSpecHttpRouteMatchPathArgs(
            exact = exact,
            regex = regex,
        )
}
